@@ -1,5 +1,8 @@
 
-from inspect import getargspec
+try:
+    from inspect import getfullargspec
+except ImportError:  # PY2
+    from inspect import getargspec as getfullargspec
 
 from nitime import descriptors as desc
 
@@ -16,7 +19,7 @@ class BaseAnalyzer(desc.ResetMixin):
 
     @desc.setattr_on_read
     def parameterlist(self):
-        plist = getargspec(self.__init__).args
+        plist = getfullargspec(self.__init__).args
         plist.remove('self')
         plist.remove('input')
         return plist
